guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

01/01: gnu: evolution: Wrap with required path variables.


From: guix-commits
Subject: 01/01: gnu: evolution: Wrap with required path variables.
Date: Mon, 16 Sep 2019 06:23:16 -0400 (EDT)

nckx pushed a commit to branch master
in repository guix.

commit ad6e168b3f29576d92b00725dedbb38cd5f05e46
Author: Martin Becze <address@hidden>
Date:   Fri Sep 6 06:35:34 2019 -0400

    gnu: evolution: Wrap with required path variables.
    
    Fixes <https://debbugs.gnu.org/cgi/bugreport.cgi?bug=36896>.
    
    * gnu/packages/gnome.scm (evolution)[arguments]: Add a ‘wrap-program’
    phase.
    
    Signed-off-by: Tobias Geerinckx-Rice <address@hidden>
---
 gnu/packages/gnome.scm | 20 ++++++++++++++++----
 1 file changed, 16 insertions(+), 4 deletions(-)

diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 5dc18b3..f2edf92 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -40,6 +40,7 @@
 ;;; Copyright © 2019 Jelle Licht <address@hidden>
 ;;; Copyright © 2019 Jonathan Frederickson <address@hidden>
 ;;; Copyright © 2019 Maxim Cournoyer <address@hidden>
+;;; Copyright © 2019 Martin Becze <address@hidden>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -8122,11 +8123,21 @@ generic enough to work for everyone.")
     (build-system cmake-build-system)
     (arguments
      `(#:configure-flags
-       (list "-DENABLE_PST_IMPORT=OFF"    ; libpst is not packaged
-             "-DENABLE_LIBCRYPTUI=OFF"))) ; libcryptui hasn't seen a release
-                                          ; in four years and cannot be built.
+       (list "-DENABLE_PST_IMPORT=OFF"  ; libpst is not packaged
+             "-DENABLE_LIBCRYPTUI=OFF") ; libcryptui hasn't seen a release
+                                        ; in four years and cannot be built
+       #:phases
+       (modify-phases %standard-phases
+         (add-after 'install 'wrap-program
+           (lambda* (#:key outputs #:allow-other-keys)
+             (let ((out (assoc-ref outputs "out")))
+               (wrap-program (string-append out "/bin/evolution")
+                 `("XDG_DATA_DIRS" ":" prefix (,(getenv "XDG_DATA_DIRS")))
+                 `("GSETTINGS_SCHEMA_DIR" =
+                   (,(string-append out "/share/glib-2.0/schemas")))))
+             #t)))))
     (native-inputs
-     `(("glib" ,glib "bin")               ; glib-mkenums
+     `(("glib" ,glib "bin")             ; glib-mkenums
        ("pkg-config" ,pkg-config)
        ("intltool" ,intltool)
        ("itstool" ,itstool)))
@@ -8134,6 +8145,7 @@ generic enough to work for everyone.")
      `(("enchant" ,enchant)
        ("evolution-data-server" ,evolution-data-server) ; must be the same 
version
        ("gcr" ,gcr)
+       ("gsettings-desktop-schemas" ,gsettings-desktop-schemas)
        ("gnome-autoar" ,gnome-autoar)
        ("gnome-desktop" ,gnome-desktop)
        ("gtkspell3" ,gtkspell3)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]